# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 鉴权失败。
FAILEDOPERATION_AUTHENTICATIONFAILED = 'FailedOperation.AuthenticationFailed'

# 依赖服务错误。
FAILEDOPERATION_METACOMPILERERROR = 'FailedOperation.MetaCompilerError'

# 数据库内部错误。
INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'

# rpc调用异常。
INTERNALERROR_RPCPILOTSERVERERROR = 'InternalError.RpcPilotServerError'

# 连接器不存在。
INVALIDPARAMETERVALUE_CONNECTORNOTEXIST = 'InvalidParameterValue.ConnectorNotExist'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'
